From: tip-bot for Mark Rutland <tipbot@zytor.com>
To: linux-tip-commits@vger.kernel.org
Cc: linux-kernel@vger.kernel.org, torvalds@linux-foundation.org,
mingo@kernel.org, bp@alien8.de, tglx@linutronix.de,
thor.thayer@linux.intel.com, peterz@infradead.org, hpa@zytor.com,
paulmck@linux.vnet.ibm.com, mark.rutland@arm.com
Subject: [tip:locking/core] locking/atomics, EDAC/altera: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE()
Date: Wed, 25 Oct 2017 03:16:07 -0700 [thread overview]
Message-ID: <tip-332efa6374de75c622b782569b16bb50fd722cf5@git.kernel.org> (raw)
In-Reply-To: <1508792849-3115-2-git-send-email-paulmck@linux.vnet.ibm.com>
Commit-ID: 332efa6374de75c622b782569b16bb50fd722cf5
Gitweb: https://git.kernel.org/tip/332efa6374de75c622b782569b16bb50fd722cf5
Author: Mark Rutland <mark.rutland@arm.com>
AuthorDate: Mon, 23 Oct 2017 14:07:12 -0700
Committer: Ingo Molnar <mingo@kernel.org>
CommitDate: Wed, 25 Oct 2017 11:00:56 +0200
locking/atomics, EDAC/altera: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE()
For several reasons, it is desirable to use {READ,WRITE}_ONCE() in
preference to ACCESS_ONCE(), and new code is expected to use one of the
former. So far, there's been no reason to change most existing uses of
ACCESS_ONCE(), as these aren't currently harmful.
However, for some features it is necessary to instrument reads and
writes separately, which is not possible with ACCESS_ONCE(). This
distinction is critical to correct operation.
It's possible to transform the bulk of kernel code using the Coccinelle
script below. However, this doesn't handle comments, leaving references
to ACCESS_ONCE() instances which have been removed. As a preparatory
step, this patch converts the Altera EDAC code and comments to use
{READ,WRITE}_ONCE() consistently.
----
virtual patch
@ depends on patch @
expression E1, E2;
@@
- ACCESS_ONCE(E1) = E2
+ WRITE_ONCE(E1, E2)
@ depends on patch @
expression E;
@@
- ACCESS_ONCE(E)
+ READ_ONCE(E)
----
Signed-off-by: Mark Rutland <mark.rutland@arm.com>
Signed-off-by: Paul E. McKenney <paulmck@linux.vnet.ibm.com>
Acked-by: Thor Thayer <thor.thayer@linux.intel.com>
Cc: Borislav Petkov <bp@alien8.de>
Cc: Linus Torvalds <torvalds@linux-foundation.org>
Cc: Peter Zijlstra <peterz@infradead.org>
Cc: Thomas Gleixner <tglx@linutronix.de>
Cc: davem@davemloft.net
Cc: linux-arch@vger.kernel.org
Cc: mpe@ellerman.id.au
Cc: shuah@kernel.org
Cc: snitzer@redhat.com
Cc: tj@kernel.org
Cc: viro@zeniv.linux.org.uk
Cc: will.deacon@arm.com
Link: http://lkml.kernel.org/r/1508792849-3115-2-git-send-email-paulmck@linux.vnet.ibm.com
Signed-off-by: Ingo Molnar <mingo@kernel.org>
---
drivers/edac/altera_edac.c | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)
diff --git a/drivers/edac/altera_edac.c b/drivers/edac/altera_edac.c
index 346c498..11d6419 100644
--- a/drivers/edac/altera_edac.c
+++ b/drivers/edac/altera_edac.c
@@ -175,11 +175,11 @@ static ssize_t altr_sdr_mc_err_inject_write(struct file *file,
/*
* To trigger the error, we need to read the data back
* (the data was written with errors above).
* The ACCESS_ONCE macros and printk are used to prevent the
* the compiler optimizing these reads out.
*/
- reg = ACCESS_ONCE(ptemp[0]);
- read_reg = ACCESS_ONCE(ptemp[1]);
+ reg = READ_ONCE(ptemp[0]);
+ read_reg = READ_ONCE(ptemp[1]);
/* Force Read */
rmb();
@@ -618,7 +618,7 @@ static ssize_t altr_edac_device_trig(struct file *file,
for (i = 0; i < (priv->trig_alloc_sz / sizeof(*ptemp)); i++) {
/* Read data so we're in the correct state */
rmb();
- if (ACCESS_ONCE(ptemp[i]))
+ if (READ_ONCE(ptemp[i]))
result = -1;
/* Toggle Error bit (it is latched), leave ECC enabled */
writel(error_mask, (drvdata->base + priv->set_err_ofst));
@@ -635,7 +635,7 @@ static ssize_t altr_edac_device_trig(struct file *file,
/* Read out written data. ECC error caused here */
for (i = 0; i < ALTR_TRIGGER_READ_WRD_CNT; i++)
- if (ACCESS_ONCE(ptemp[i]) != i)
+ if (READ_ONCE(ptemp[i]) != i)
edac_printk(KERN_ERR, EDAC_DEVICE,
"Read doesn't match written data\n");
next prev parent reply other threads:[~2017-10-25 10:20 UTC|newest]
Thread overview: 51+ messages / expand[flat|nested] mbox.gz Atom feed top
2017-10-23 21:04 [GIT PULL de-alpha] Make core code not need to know about Alpha for v4.15 Paul E. McKenney
2017-10-23 21:07 ` [PATCH 01/19] dm integrity: Kill off ACCESS_ONCE() Paul E. McKenney
2017-10-25 10:15 ` [tip:locking/core] locking/atomics, dm-integrity: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE() tip-bot for Mark Rutland
2017-10-23 21:07 ` [PATCH 02/19] EDAC, altera: Kill off ACCESS_ONCE() Paul E. McKenney
2017-10-25 10:16 ` tip-bot for Mark Rutland [this message]
2017-10-23 21:07 ` [PATCH 03/19] firmware/ivc: " Paul E. McKenney
2017-10-25 10:16 ` [tip:locking/core] locking/atomics, firmware/ivc: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE() tip-bot for Mark Rutland
2017-10-23 21:07 ` [PATCH 04/19] fs: dcache: Kill off ACCESS_ONCE() Paul E. McKenney
2017-10-25 10:16 ` [tip:locking/core] locking/atomics, fs/dcache: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE() tip-bot for Mark Rutland
2017-10-23 21:07 ` [PATCH 05/19] fs: ncpfs: Kill off ACCESS_ONCE() Paul E. McKenney
2017-10-25 10:17 ` [tip:locking/core] locking/atomics, fs/ncpfs: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE() tip-bot for Mark Rutland
2017-10-23 21:07 ` [PATCH 06/19] media: dvb_ringbuffer: Kill off ACCESS_ONCE() Paul E. McKenney
2017-10-25 10:17 ` [tip:locking/core] locking/atomics, media/dvb_ringbuffer: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE() tip-bot for Mark Rutland
2017-10-23 21:07 ` [PATCH 07/19] net: netlink/netfilter: Kill off ACCESS_ONCE() Paul E. McKenney
2017-10-25 10:18 ` [tip:locking/core] locking/atomics, net/netlink/netfilter: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE() tip-bot for Mark Rutland
2017-10-23 21:07 ` [PATCH 08/19] net/ipv4/tcp_input.c: Kill off ACCESS_ONCE() Paul E. McKenney
2017-10-25 10:18 ` [tip:locking/core] locking/atomics, net/ipv4/tcp_input.c: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE() tip-bot for Mark Rutland
2017-10-23 21:07 ` [PATCH 09/19] net: average: Kill off ACCESS_ONCE() Paul E. McKenney
2017-10-24 5:58 ` Johannes Berg
2017-10-24 9:34 ` Ingo Molnar
2017-10-24 13:49 ` Paul E. McKenney
2017-10-25 10:18 ` [tip:locking/core] locking/atomics, net/average: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE() tip-bot for Mark Rutland
2017-10-23 21:07 ` [PATCH 10/19] samples: mic/mpssd/mpssd.c: Kill off ACCESS_ONCE() Paul E. McKenney
2017-10-25 10:19 ` [tip:locking/core] locking/atomics, samples/mic/mpssd/mpssd.c: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE() tip-bot for Mark Rutland
2017-10-23 21:07 ` [PATCH 11/19] selftests/powerpc: Kill off ACCESS_ONCE() Paul E. McKenney
2017-10-25 10:19 ` [tip:locking/core] locking/atomics, selftests/powerpc: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE() tip-bot for Mark Rutland
2017-10-23 21:07 ` [PATCH 12/19] workqueue: Kill off ACCESS_ONCE() Paul E. McKenney
2017-10-25 10:20 ` [tip:locking/core] locking/atomics, workqueue: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE() tip-bot for Mark Rutland
2017-10-23 21:07 ` [PATCH 13/19] rcutorture: formal: Prepare for ACCESS_ONCE() removal Paul E. McKenney
2017-10-25 10:20 ` [tip:locking/core] locking/atomics, rcutorture/formal: " tip-bot for Mark Rutland
2017-10-23 21:07 ` [PATCH 14/19] doc: filesystems: Kill off ACCESS_ONCE() Paul E. McKenney
2017-10-25 10:21 ` [tip:locking/core] locking/atomics, doc/filesystems: Convert ACCESS_ONCE() references tip-bot for Paul E. McKenney
2017-10-23 21:07 ` [PATCH 15/19] mm: Kill off ACCESS_ONCE() Paul E. McKenney
2017-10-25 10:21 ` [tip:locking/core] locking/atomics, mm: Convert ACCESS_ONCE() to READ_ONCE()/WRITE_ONCE() tip-bot for Paul E. McKenney
2017-10-23 21:07 ` [PATCH 16/19] linux/compiler.h: Split into compiler.h and compiler-types.h Paul E. McKenney
2017-10-24 9:25 ` Ingo Molnar
2017-10-24 9:30 ` Will Deacon
2017-10-24 9:52 ` Ingo Molnar
2017-10-23 21:07 ` [PATCH 17/19] locking/barriers: Kill lockless_dereference Paul E. McKenney
2017-10-24 9:31 ` Ingo Molnar
2017-10-24 9:44 ` Will Deacon
2017-10-24 9:54 ` Ingo Molnar
2017-10-24 10:23 ` Will Deacon
2017-10-23 21:07 ` [PATCH 18/19] alpha: atomics: Add smp_read_barrier_depends() to release/relaxed atomics Paul E. McKenney
2017-10-23 21:07 ` [PATCH 19/19] COCCINELLE: treewide: kill off ACCESS_ONCE() Paul E. McKenney
2017-10-25 10:21 ` [tip:locking/core] locking/atomics: COCCINELLE/treewide: Convert trivial ACCESS_ONCE() patterns to READ_ONCE()/WRITE_ONCE() tip-bot for Mark Rutland
2017-10-24 9:32 ` [GIT PULL de-alpha] Make core code not need to know about Alpha for v4.15 Ingo Molnar
2017-10-25 8:45 ` Ingo Molnar
2017-10-25 8:54 ` Paul E. McKenney
2017-10-25 9:04 ` Ingo Molnar
2017-10-25 13:18 ` Paul E. McKenney
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tip-332efa6374de75c622b782569b16bb50fd722cf5@git.kernel.org \
--to=tipbot@zytor.com \
--cc=bp@alien8.de \
--cc=hpa@zytor.com \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=mark.rutland@arm.com \
--cc=mingo@kernel.org \
--cc=paulmck@linux.vnet.ibm.com \
--cc=peterz@infradead.org \
--cc=tglx@linutronix.de \
--cc=thor.thayer@linux.intel.com \
--cc=torvalds@linux-foundation.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -175,11 +175,11 @@ static ssize_t altr_sdr_mc_err_inject_write(struct file *file,
* To trigger the error, we need to read the data back
* (the data was written with errors above).
- * The ACCESS_ONCE macros and printk are used to prevent the
+ * The READ_ONCE macros and printk are used to prevent the
* the compiler optimizing these reads out.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Powered by JetHome